@@ -4,10 +4,12 @@ from bs4 import BeautifulSoup
 from requests import get
 
 import utils
+from utils.config import get_config
 
 
 def author_ipr(author_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml', max_workers=None):
-    url = f'http://sinta.ristekbrin.go.id/authors/detail?id={author_id}&view=ipr'
+    domain = get_config()['domain']
+    url = f'{domain}/authors/detail?id={author_id}&view=ipr'
     html = get(url)
     soup = BeautifulSoup(html.content, 'html.parser')
     page_info = soup.select('.uk-width-large-1-2.table-footer')
@@ -22,7 +24,8 @@ def author_ipr(author_id, output_format='dictionary', pretty_print=None, xml_lib
 
 
 def worker(author_id, page, worker_result):
-    url = f'http://sinta.ristekbrin.go.id/authors/detail?page={page}&id={author_id}&view=ipr'
+    domain = get_config()['domain']
+    url = f'{domain}/authors/detail?page={page}&id={author_id}&view=ipr'
     html = get(url)
     soup = BeautifulSoup(html.content, 'html.parser')
     data = parse(soup)
